Struct Color

pub struct Color {
    pub r: u8,
    pub g: u8,
    pub b: u8,
}
A simple struct to represent the color in the RGB format.

Fields

r: u8

A number between 0 and 255 which represents Red spectrum.

g: u8

A number between 0 and 255 which represents Green spectrum.

b: u8

A number between 0 and 255 which represents Blue spectrum.

Implementations

Source

impl Color

pub fn new(hex_color: &str) -> Self

Creates a new instance of Color with the hex code

use markterm::Color;
let white = Color::new("#FFF");
assert_eq!(white.r, 255)
pub fn rgb(&self) -> String

Returns a semicolon delimited rgb value

Example
use markterm::Color;

let white = Color::new("#FFF");
assert_eq!("255;255;255", white.rgb());